@@ -66,6 +66,14 @@ def register_core_options():
                          default='all',
                          help_msg=help_msg)
 
+    help_msg = ('Fields to include in the presentation of SIMPLE test '
+                'failures.  Accepted values: status, stdout, stderr.')
+    stgs.register_option(section='simpletests.status',
+                         key='failure_fields',
+                         key_type=list,
+                         default=['status', 'stdout', 'stderr'],
+                         help_msg=help_msg)
+
     help_msg = ('The amount of time to give to the test process after '
                 'it it has been interrupted (such as with CTRL+C)')
     stgs.register_option(section='runner.timeout',
@@ -166,6 +174,16 @@ def register_core_options():
                          default='utf-8',
                          help_msg=help_msg)
 
+    # All settings starting with 'runner.' will be passed to runner
+    # exec-test runner config
+    help_msg = ('Use a custom exit code list to consider a test as skipped. '
+                'This is only used by exec-test runners. Default is [].')
+    stgs.register_option(section='runner.exectest.exitcodes',
+                         key='skip',
+                         default=[],
+                         key_type=list,
+                         help_msg=help_msg)
+
 
 def initialize_plugin_infrastructure():
     help_msg = 'Plugins that will not be loaded and executed'
