@@ -1,5 +1,6 @@
 #!/usr/bin/env python3
 
+import abc
 import argparse
 import base64
 import collections
@@ -15,6 +16,7 @@ import sys
 import tempfile
 import time
 import unittest
+from uuid import uuid1
 
 try:
     import pkg_resources
@@ -41,12 +43,12 @@ RUNNERS_REGISTRY_STANDALONE_EXECUTABLE = {}
 RUNNERS_REGISTRY_PYTHON_CLASS = {}
 
 
-def check_tasks_requirements(tasks, runners_registry=None):
+def check_runnables_runner_requirements(runnables, runners_registry=None):
     """
-    Checks if tasks have runner requirements fulfilled
+    Checks if runnables have runner requirements fulfilled
 
-    :param tasks: the tasks whose runner requirements will be checked
-    :type tasks: list of :class:`Task`
+    :param runnables: the tasks whose runner requirements will be checked
+    :type runnable: list of :class:`Runnable`
     :param runners_registry: a registry with previously found (and not found)
                              runners keyed by a task's runnable kind. Defaults
                              to :attr:`RUNNERS_REGISTRY_STANDALONE_EXECUTABLE`
@@ -60,12 +62,13 @@ def check_tasks_requirements(tasks, runners_registry=None):
         runners_registry = RUNNERS_REGISTRY_STANDALONE_EXECUTABLE
     ok = []
     missing = []
-    for task in tasks:
-        runner = task.runnable.pick_runner_command(runners_registry)
+
+    for runnable in runnables:
+        runner = runnable.pick_runner_command(runners_registry)
         if runner:
-            ok.append(task)
+            ok.append(runnable)
         else:
-            missing.append(task)
+            missing.append(runnable)
     return (ok, missing)
 
 
@@ -255,10 +258,10 @@ class Runnable:
         # Looking for the file only avoids an attempt to load the module
         # and should be a lot faster
         core_dir = os.path.dirname(os.path.abspath(__file__))
-        module_name = "nrunner_%s" % self.kind.replace('-', '_')
+        module_name = self.kind.replace('-', '_')
         module_filename = '%s.py' % module_name
-        if os.path.exists(os.path.join(core_dir, module_filename)):
-            full_module_name = 'avocado.core.%s' % module_name
+        if os.path.exists(os.path.join(core_dir, 'runners', module_filename)):
+            full_module_name = 'avocado.core.runners.%s' % module_name
             candidate_cmd = [sys.executable, '-m', full_module_name]
             if self.is_kind_supported_by_runner_command(candidate_cmd):
                 runners_registry[self.kind] = candidate_cmd
@@ -310,7 +313,7 @@ class Runnable:
         raise ValueError('Unsupported kind of runnable: %s' % self.kind)
 
 
-class BaseRunner:
+class BaseRunner(metaclass=abc.ABCMeta):
     """
     Base interface for a Runner
     """
@@ -318,7 +321,8 @@ class BaseRunner:
     def __init__(self, runnable):
         self.runnable = runnable
 
-    def prepare_status(self, status_type, additional_info=None):
+    @staticmethod
+    def prepare_status(status_type, additional_info=None):
         """Prepare a status dict with some basic information.
 
         This will add the keyword 'status' and 'time' to all status.
@@ -331,15 +335,20 @@ class BaseRunner:
 
         :rtype: dict
         """
-        status = {'status': status_type,
-                  'time': time.monotonic()}
-
+        status = {}
         if isinstance(additional_info, dict):
-            status.update(additional_info)
+            status = additional_info
+        status.update({'status': status_type,
+                       'time': time.monotonic()})
         return status
 
+    @abc.abstractmethod
     def run(self):
-        yield {}
+        """Runner main method
+
+        Yields dictionary as output, containing status as well as relevant
+        information concerning the results.
+        """
 
 
 class NoOpRunner(BaseRunner):
@@ -376,6 +385,11 @@ class ExecRunner(BaseRunner):
        process
     """
 
+    def _process_final_status(self, process,
+                              stdout=None, stderr=None):  # pylint: disable=W0613
+        return self.prepare_status('finished',
+                                   {'returncode': process.returncode})
+
     def run(self):
         env = None
         if self.runnable.kwargs:
@@ -410,11 +424,9 @@ class ExecRunner(BaseRunner):
                     now > next_execution_state_mark):
                 most_current_execution_state_time = now
                 yield self.prepare_status('running')
-
-        return_code = process.returncode
-        yield self.prepare_status('finished', {'returncode': return_code,
-                                               'stdout': stdout,
-                                               'stderr': stderr})
+        yield self.prepare_status('running', {'type': 'stdout', 'log': stdout})
+        yield self.prepare_status('running', {'type': 'stderr', 'log': stderr})
+        yield self._process_final_status(process, stdout, stderr)
 
 
 RUNNERS_REGISTRY_PYTHON_CLASS['exec'] = ExecRunner
@@ -431,22 +443,23 @@ class ExecTestRunner(ExecRunner):
     Runnable attributes usage is identical to :class:`ExecRunner`
     """
 
-    def run(self):
+    def _process_final_status(self, process,
+                              stdout=None, stderr=None):  # pylint: disable=W0613
         # Since Runners are standalone, and could be executed on a remote
         # machine in an "isolated" way, there is no way to assume a default
         # value, at this moment.
         skip_codes = self.runnable.config.get('runner.exectest.exitcodes.skip',
                                               [])
-        for most_current_execution_state in super(ExecTestRunner, self).run():
-            returncode = most_current_execution_state.get('returncode')
-            if returncode is not None:
-                if returncode in skip_codes:
-                    most_current_execution_state['result'] = 'skip'
-                elif returncode == 0:
-                    most_current_execution_state['result'] = 'pass'
-                else:
-                    most_current_execution_state['result'] = 'fail'
-            yield most_current_execution_state
+        final_status = {}
+        if process.returncode in skip_codes:
+            final_status['result'] = 'skip'
+        elif process.returncode == 0:
+            final_status['result'] = 'pass'
+        else:
+            final_status['result'] = 'fail'
+
+        final_status['returncode'] = process.returncode
+        return self.prepare_status('finished', final_status)
 
 
 RUNNERS_REGISTRY_PYTHON_CLASS['exec-test'] = ExecTestRunner
@@ -541,6 +554,9 @@ class PythonUnittestRunner(BaseRunner):
                 yield self.prepare_status('running')
 
         status = queue.get()
+        yield self.prepare_status('running',
+                                  {'type': 'stdout',
+                                   'log': status.pop('output').encode()})
         status['time'] = time.monotonic()
         yield status
 
@@ -643,15 +659,29 @@ class Task:
     While a runnable describes what to be run, and gets run by a
     runner, a task should be a unique entity to track its state,
     that is, whether it is pending, is running or has finished.
-
-    :param identifier:
-    :param runnable:
     """
 
-    def __init__(self, identifier, runnable, status_uris=None,
+    def __init__(self, runnable, identifier=None, status_uris=None,
                  known_runners=None):
-        self.identifier = identifier
+        """Instantiates a new Task.
+
+        :param runnable: the "description" of what the task should run.
+        :type runnable: :class:`avocado.core.nrunner.Runnable`
+        :param identifier: any identifier that is guaranteed to be unique
+                           within the context of a Job. A recommended value
+                           is a :class:`avocado.core.test_id.TestID` instance
+                           when a task represents a test, because besides the
+                           uniqueness aspect, it's also descriptive.  If an
+                           identifier is not given, an automatically generated
+                           one will be set.
+        :param status_uri: the URIs for the status servers that this task
+                           should send updates to.
+        :type status_uri: list
+        :param known_runners: a mapping of runnable kinds to runners.
+        :type known_runners: dict
+        """
         self.runnable = runnable
+        self.identifier = identifier or str(uuid1())
         self.status_services = []
         if status_uris is not None:
             for status_uri in status_uris:
@@ -661,6 +691,7 @@ class Task:
         self.known_runners = known_runners
         self.spawn_handle = None
         self.output_dir = None
+        self.metadata = {}
 
     def __repr__(self):
         fmt = '<Task identifier="{}" runnable="{}" status_services="{}"'
@@ -702,7 +733,7 @@ class Task:
                             *runnable_recipe.get('args', ()),
                             config=runnable_recipe.get('config'))
         status_uris = recipe.get('status_uris')
-        return cls(identifier, runnable, status_uris, known_runners)
+        return cls(runnable, identifier, status_uris, known_runners)
 
     def get_command_args(self):
         """
@@ -841,7 +872,8 @@ class BaseRunnerApp:
                 for c in inspect.getmembers(self, inspect.ismethod)
                 if c[0].startswith(prefix)}
 
-    def _get_command_method_help_message(self, command_method):
+    @staticmethod
+    def _get_command_method_help_message(command_method):
         help_message = ''
         docstring = command_method.__doc__
         if docstring:
@@ -944,7 +976,7 @@ class BaseRunnerApp:
         :type args: dict
         """
         runnable = Runnable.from_args(args)
-        task = Task(args.get('identifier'), runnable,
+        task = Task(runnable, args.get('identifier'),
                     args.get('status_uri', []),
                     known_runners=self.RUNNABLE_KINDS_CAPABLE)
         for status in task.run():
