@@ -183,7 +183,8 @@ class ConfigOption:
 
         return args
 
-    def _as_list(self, value):
+    @staticmethod
+    def _as_list(value):
         if value == '':
             return []
 
@@ -394,7 +395,7 @@ class Settings:
             msg = "Parser already registered for this namespace"
             raise SettingsError(msg)
 
-        option.add_argparser(parser, short_arg, long_arg, positional_arg,
+        option.add_argparser(parser, long_arg, short_arg, positional_arg,
                              choices, nargs, metavar, required, action)
 
     def as_dict(self, regex=None):
