@@ -21,13 +21,14 @@ import os
 from datetime import datetime
 
 from avocado.core import data_dir, exit_codes, safeloader
-from avocado.core.nrunner import Task
+from avocado.core.nrunner import Runnable
 from avocado.core.output import LOG_UI
 from avocado.core.plugin_interfaces import CLICmd, JobPreTests
 from avocado.core.settings import settings
 from avocado.utils import data_structures
 from avocado.utils.asset import SUPPORTED_OPERATORS, Asset
 from avocado.utils.astring import iter_tabular_output
+from avocado.utils.data_structures import DataSize, InvalidDataSize
 from avocado.utils.output import display_data_size
 
 
@@ -249,9 +250,9 @@ class FetchAssetJob(JobPreTests):  # pylint: disable=R0903
         for suite in job.test_suites:
             for test in suite.tests:
                 # ignore nrunner/resolver based test suites that contain
-                # task, because the requirements resolution planned is
+                # runnable, because the requirements resolution planned is
                 # completely different from the traditional job runner
-                if isinstance(test, Task):
+                if isinstance(test, Runnable):
                     continue
                 # fetch assets only on instrumented tests
                 if isinstance(test[0], str):
@@ -268,6 +269,14 @@ class Assets(CLICmd):
     name = 'assets'
     description = 'Manage assets'
 
+    @staticmethod
+    def _count_filter_args(config):
+        sub_command = config.get('assets_subcommand')
+        args = [config.get("assets.{}.days".format(sub_command)),
+                config.get("assets.{}.size_filter".format(sub_command)),
+                config.get("assets.{}.overall_limit".format(sub_command))]
+        return len([a for a in args if a is not None])
+
     def configure(self, parser):
         """
         Add the subparser for the assets action.
@@ -299,6 +308,20 @@ class Assets(CLICmd):
                                      long_arg='--by-days',
                                      parser=subparser)
 
+            help_msg = ("Filter will be based on a overall system limit "
+                        "threshold in bytes (with assets orded by last "
+                        "access) or with a suffix unit. Valid suffixes are: ")
+            help_msg += ','.join(DataSize.MULTIPLIERS.keys())
+
+            settings.register_option(section=section,
+                                     key='overall_limit',
+                                     help_msg=help_msg,
+                                     default=None,
+                                     key_type=str,
+                                     metavar="LIMIT",
+                                     long_arg='--by-overall-limit',
+                                     parser=subparser)
+
         parser = super(Assets, self).configure(parser)
 
         subcommands = parser.add_subparsers(dest='assets_subcommand')
@@ -374,12 +397,13 @@ class Assets(CLICmd):
     def handle_purge(self, config):
         days = config.get('assets.purge.days')
         size_filter = config.get('assets.purge.size_filter')
-        if (days is None and size_filter is None) \
-                or (days is not None and size_filter is not None):
+        overall_limit = config.get('assets.purge.overall_limit')
+
+        if self._count_filter_args(config) != 1:
             msg = ("You should choose --by-size-filter or --by-days. "
                    "For help, run: avocado assets purge --help")
             LOG_UI.error(msg)
-            return
+            return exit_codes.AVOCADO_FAIL
 
         cache_dirs = data_dir.get_cache_dirs()
         try:
@@ -387,17 +411,30 @@ class Assets(CLICmd):
                 Asset.remove_assets_by_unused_for_days(days, cache_dirs)
             elif size_filter is not None:
                 Asset.remove_assets_by_size(size_filter, cache_dirs)
+            elif overall_limit is not None:
+                try:
+                    size = DataSize(overall_limit).b
+                    Asset.remove_assets_by_overall_limit(size, cache_dirs)
+                except InvalidDataSize:
+                    error_msg = "You are using an invalid suffix. "
+                    error_msg += "Use one of the following values: "
+                    error_msg += ",".join(DataSize.MULTIPLIERS.keys())
+                    LOG_UI.error(error_msg)
+                    return exit_codes.AVOCADO_FAIL
+
         except (FileNotFoundError, OSError) as e:
             LOG_UI.error("Could not remove asset: %s", e)
+            return exit_codes.AVOCADO_FAIL
+        return exit_codes.AVOCADO_ALL_OK
 
     def handle_list(self, config):
         days = config.get('assets.list.days')
         size_filter = config.get('assets.list.size_filter')
-        if (days is not None and size_filter is not None):
+        if self._count_filter_args(config) == 2:
             msg = ("You should choose --by-size-filter or --by-days. "
                    "For help, run: avocado assets list --help")
             LOG_UI.error(msg)
-            return
+            return exit_codes.AVOCADO_FAIL
 
         # IMO, this should get data from config instead. See #4443
         cache_dirs = data_dir.get_cache_dirs()
@@ -411,7 +448,7 @@ class Assets(CLICmd):
                 assets = Asset.get_all_assets(cache_dirs)
         except (FileNotFoundError, OSError) as e:
             LOG_UI.error("Could get assets: %s", e)
-            return
+            return exit_codes.AVOCADO_FAIL
 
         matrix = []
         for asset in assets:
@@ -432,7 +469,8 @@ class Assets(CLICmd):
             for line in output:
                 LOG_UI.info(line)
 
-    def handle_fetch(self, config):
+    @staticmethod
+    def handle_fetch(config):
         exitcode = exit_codes.AVOCADO_ALL_OK
         # fetch assets from instrumented tests
         for test_file in config.get('assets.fetch.references'):
@@ -458,7 +496,8 @@ class Assets(CLICmd):
             return exit_codes.AVOCADO_ALL_OK
         return exitcode
 
-    def handle_register(self, config):
+    @staticmethod
+    def handle_register(config):
         cache_dirs = data_dir.get_cache_dirs()
         name = config.get('assets.register.name')
         asset_hash = config.get('assets.register.sha1_hash')
@@ -473,12 +512,15 @@ class Assets(CLICmd):
         try:
             asset.find_asset_file()
             LOG_UI.error("Asset with name %s already registered.", name)
+            return exit_codes.AVOCADO_FAIL
         except OSError:
             try:
                 asset.fetch()
                 LOG_UI.info("Done. Now you can reference it by name %s", name)
+                return exit_codes.AVOCADO_ALL_OK
             except OSError as e:
                 LOG_UI.error(e)
+                return exit_codes.AVOCADO_FAIL
 
     def run(self, config):
         subcommand = config.get('assets_subcommand')
