@@ -17,14 +17,12 @@ NRunner based implementation of job compliant runner
 """
 
 import asyncio
-import json
 import multiprocessing
-import os
 import random
-from copy import copy
 
 from avocado.core import nrunner
 from avocado.core.dispatcher import SpawnerDispatcher
+from avocado.core.messages import MessageHandler
 from avocado.core.plugin_interfaces import CLI, Init
 from avocado.core.plugin_interfaces import Runner as RunnerInterface
 from avocado.core.settings import settings
@@ -33,7 +31,6 @@ from avocado.core.status.server import StatusServer
 from avocado.core.task.runtime import RuntimeTask
 from avocado.core.task.statemachine import TaskStateMachine, Worker
 from avocado.core.test_id import TestID
-from avocado.core.teststatus import mapping
 
 
 class RunnerInit(Init):
@@ -139,62 +136,25 @@ class Runner(RunnerInterface):
     name = 'nrunner'
     description = 'nrunner based implementation of job compliant runner'
 
-    def _save_to_file(self, filename, buff, mode='wb'):
-        with open(filename, mode) as fp:
-            fp.write(buff)
-
-    def _populate_task_logdir(self, base_path, task, statuses, debug=False):
-        # We are copying here to avoid printing duplicated information
-        local_statuses = copy(statuses)
-        last = local_statuses[-1]
-        try:
-            stdout = last.pop('stdout')
-        except KeyError:
-            stdout = None
-        try:
-            stderr = last.pop('stderr')
-        except KeyError:
-            stderr = None
-
-        # Create task dir
-        task_path = os.path.join(base_path, task.identifier.str_filesystem)
-        os.makedirs(task_path, exist_ok=True)
-
-        # Save stdout and stderr
-        if stdout is not None:
-            stdout_file = os.path.join(task_path, 'stdout')
-            self._save_to_file(stdout_file, stdout)
-        if stderr is not None:
-            stderr_file = os.path.join(task_path, 'stderr')
-            self._save_to_file(stderr_file, stderr)
-
-        # Save debug
-        if debug:
-            debug = os.path.join(task_path, 'debug')
-            with open(debug, 'w') as fp:
-                json.dump(local_statuses, fp)
-
-        data_file = os.path.join(task_path, 'data')
-        with open(data_file, 'w') as fp:
-            fp.write("{}\n".format(task.output_dir))
-
-    def _get_all_runtime_tasks(self, test_suite):
-        result = []
+    @staticmethod
+    def _get_all_runtime_tasks(test_suite):
+        runtime_tasks = []
         no_digits = len(str(len(test_suite)))
-        for index, task in enumerate(test_suite.tests, start=1):
-            task.known_runners = nrunner.RUNNERS_REGISTRY_PYTHON_CLASS
+        status_uris = [test_suite.config.get('nrunner.status_server_uri')]
+        for index, runnable in enumerate(test_suite.tests, start=1):
             # this is all rubbish data
             if test_suite.name:
                 prefix = "{}-{}".format(test_suite.name, index)
             else:
                 prefix = index
             test_id = TestID(prefix,
-                             task.runnable.uri,
+                             runnable.uri,
                              None,
                              no_digits)
-            task.identifier = test_id
-            result.append(RuntimeTask(task))
-        return result
+            task = nrunner.Task(runnable, test_id, status_uris,
+                                nrunner.RUNNERS_REGISTRY_PYTHON_CLASS)
+            runtime_tasks.append(RuntimeTask(task))
+        return runtime_tasks
 
     def _start_status_server(self, status_server_listen):
         # pylint: disable=W0201
@@ -207,60 +167,26 @@ class Runner(RunnerInterface):
     async def _update_status(self, job):
         tasks_by_id = {str(runtime_task.task.identifier): runtime_task.task
                        for runtime_task in self.tasks}
+        message_handler = MessageHandler()
         while True:
             try:
-                (task_id, status, _) = self.status_repo.status_journal_summary.pop(0)
+                (task_id, _, _, index) = \
+                    self.status_repo.status_journal_summary.pop(0)
 
             except IndexError:
                 await asyncio.sleep(0.05)
                 continue
 
+            message = self.status_repo.get_task_data(task_id, index)
             task = tasks_by_id.get(task_id)
-            early_state = {'name': task.identifier,
-                           'job_logdir': job.logdir,
-                           'job_unique_id': job.unique_id}
-            if status == 'started':
-                job.result.start_test(early_state)
-                job.result_events_dispatcher.map_method('start_test',
-                                                        job.result,
-                                                        early_state)
-            elif status == 'finished':
-                this_task_data = self.status_repo.get_task_data(task_id)
-                last_task_status = this_task_data[-1]
-                test_state = last_task_status.copy()
-                test_state['status'] = last_task_status.get('result').upper()
-                test_state.update(early_state)
-
-                time_start = this_task_data[0]['time']
-                time_end = last_task_status['time']
-                time_elapsed = time_end - time_start
-                test_state['time_start'] = time_start
-                test_state['time_end'] = time_end
-                test_state['time_elapsed'] = time_elapsed
-
-                # fake log dir, needed by some result plugins such as HTML
-                if 'logdir' not in test_state:
-                    test_state['logdir'] = ''
-
-                base_path = os.path.join(job.logdir, 'test-results')
-                self._populate_task_logdir(base_path,
-                                           task,
-                                           this_task_data,
-                                           job.config.get('core.debug'))
-
-                job.result.check_test(test_state)
-                job.result_events_dispatcher.map_method('end_test',
-                                                        job.result,
-                                                        test_state)
-
-                if not mapping[test_state['status']]:
-                    self.summary.add("FAIL")
+            message_handler.process_message(message, task, job)
 
     def run_suite(self, job, test_suite):
         # pylint: disable=W0201
         self.summary = set()
 
-        test_suite.tests, _ = nrunner.check_tasks_requirements(test_suite.tests)
+        test_suite.tests, _ = nrunner.check_runnables_runner_requirements(
+            test_suite.tests)
         job.result.tests_total = test_suite.size  # no support for variants yet
 
         listen = test_suite.config.get('nrunner.status_server_listen')
