@@ -78,7 +78,8 @@ class Session:
     def __exit__(self, _exc_type, _exc_value, _traceback):
         self.quit()
 
-    def _dash_o_opts_to_str(self, opts):
+    @staticmethod
+    def _dash_o_opts_to_str(opts):
         """
         Transforms tuples into options that should be given by "-o Key=Val"
         """
@@ -127,6 +128,11 @@ class Session:
     def _check(self):
         return self._master_command('check')
 
+    def cleanup_master(self):
+        """Removes master file if exists."""
+        if self.control_master:
+            os.unlink(self.control_master)
+
     def connect(self):
         """
         Establishes the connection to the remote endpoint
@@ -168,6 +174,15 @@ class Session:
             self._connection = master
         return self._check()
 
+    @property
+    def control_master(self):
+        control = "~/.ssh/avocado-master-{}@{}:{}".format(self.user,
+                                                          self.host,
+                                                          self.port)
+        control = os.path.expanduser(control)
+        if os.path.exists(control):
+            return control
+
     def get_raw_ssh_command(self, command):
         """
         Returns the raw command that will be executed locally
