@@ -115,7 +115,8 @@ class ImageProviderBase:
         except HTTPError:
             raise ImageProviderError('Cannot open %s' % self.url_versions)
 
-    def get_best_version(self, versions):
+    @staticmethod
+    def get_best_version(versions):
         return max(versions)
 
     def get_versions(self):
@@ -495,9 +496,9 @@ class Image:
         if self.snapshot_dir is not None:
             new_image = os.path.join(self.snapshot_dir,
                                      os.path.basename(new_image))
-        cmd = '%s create -f qcow2 -b %s %s' % (qemu_img,
-                                               self.base_image,
-                                               new_image)
+        cmd = '%s create -f qcow2 -b %s -F qcow2 %s' % (qemu_img,
+                                                        self.base_image,
+                                                        new_image)
         process.run(cmd)
         return new_image
 
