@@ -7,7 +7,8 @@ class CancelOnException(avocado.Test):
     Test illustrating the usage of the cancel_on decorator.
     """
 
-    def test(self):
+    @staticmethod
+    def test():
         """
         This should end with CANCEL.
 
