@@ -498,11 +498,12 @@ def create_suites(args):
     # Run all static checks, unit and functional tests
     # ========================================================================
     config_check = {
-        'run.references': (glob.glob('selftests/jobs/*') +
-                           glob.glob('selftests/unit/*.py') +
-                           glob.glob('selftests/functional/*.py')),
+        'run.references': ['selftests/jobs/',
+                           'selftests/unit/',
+                           'selftests/functional/'],
         'run.test_runner': 'nrunner',
-        'run.ignore_missing_references': True
+        'run.ignore_missing_references': True,
+        'job.output.testlogs.statuses': ['FAIL']
     }
 
     if not args.disable_static_checks:
@@ -518,6 +519,13 @@ def create_suites(args):
     return suites
 
 
+def print_failed_tests(tests):
+    if tests:
+        print("Failed tests:")
+        for test in tests:
+            print(test.get('name'), test.get('status'))
+
+
 def main():
     args = parse_args()
     suites = create_suites(args)
@@ -541,7 +549,9 @@ def main():
     config = {'core.show': ['app'],
               'run.test_runner': 'nrunner'}
     with Job(config, suites) as j:
-        return j.run()
+        exit_code = j.run()
+    print_failed_tests(j.get_failed_tests())
+    return exit_code
 
 
 if __name__ == '__main__':
