@@ -1,23 +1,17 @@
 import os
-import tempfile
 import unittest
 
 from avocado.core import exit_codes
 from avocado.utils import process
 
-from .. import AVOCADO, BASEDIR, temp_dir_prefix
+from .. import AVOCADO, BASEDIR, TestCaseTmpDir
 
 
-class GetData(unittest.TestCase):
-
-    def setUp(self):
-        os.chdir(BASEDIR)
-        prefix = temp_dir_prefix(__name__, self, 'setUp')
-        self.tmpdir = tempfile.TemporaryDirectory(prefix=prefix)
+class GetData(TestCaseTmpDir):
 
     def test(self):
         test_path = os.path.join(BASEDIR, "selftests", ".data", "get_data.py")
-        cmd_line = "%s run --sysinfo=off --job-results-dir '%s' -- %s"
+        cmd_line = "%s run --disable-sysinfo --job-results-dir '%s' -- %s"
         cmd_line %= (AVOCADO, self.tmpdir.name, test_path)
         result = process.run(cmd_line)
         self.assertEqual(result.exit_status, exit_codes.AVOCADO_ALL_OK)
@@ -26,15 +20,12 @@ class GetData(unittest.TestCase):
         test_path = os.path.join(BASEDIR, "selftests", ".data", "get_data.py")
         test_variants_path = os.path.join(BASEDIR, "selftests", ".data",
                                           "get_data.py.data", "get_data.json")
-        cmd_line = ("%s run --sysinfo=off --job-results-dir '%s' "
+        cmd_line = ("%s run --disable-sysinfo --job-results-dir '%s' "
                     "--json-variants-load %s -- %s")
         cmd_line %= (AVOCADO, self.tmpdir.name, test_variants_path, test_path)
         result = process.run(cmd_line)
         self.assertEqual(result.exit_status, exit_codes.AVOCADO_ALL_OK)
 
-    def tearDown(self):
-        self.tmpdir.cleanup()
-
 
 if __name__ == '__main__':
     unittest.main()
