@@ -3,7 +3,8 @@ import sys
 import tempfile
 import unittest.mock
 
-from avocado.core import nrunner, nrunner_tap
+from avocado.core import nrunner
+from avocado.core.runners import tap as runner_tap
 
 from .. import skipUnlessPathExists, temp_dir_prefix
 
@@ -203,11 +204,15 @@ class Runner(unittest.TestCase):
         runner_klass = runnable.pick_runner_class()
         runner = runner_klass(runnable)
         results = [status for status in runner.run()]
+        stdout_result = results[-3]
+        stderr_result = results[-2]
         last_result = results[-1]
+        self.assertEqual(stdout_result['type'], 'stdout')
+        self.assertEqual(stdout_result['log'], b'')
+        self.assertEqual(stderr_result['type'], 'stderr')
+        self.assertEqual(stderr_result['log'], b'')
         self.assertEqual(last_result['status'], 'finished')
         self.assertEqual(last_result['returncode'], 0)
-        self.assertEqual(last_result['stdout'], b'')
-        self.assertEqual(last_result['stderr'], b'')
         self.assertIn('time', last_result)
 
     def test_runner_exec_test_ok(self):
@@ -216,12 +221,16 @@ class Runner(unittest.TestCase):
         runner_klass = runnable.pick_runner_class()
         runner = runner_klass(runnable)
         results = [status for status in runner.run()]
+        stdout_result = results[-3]
+        stderr_result = results[-2]
         last_result = results[-1]
+        self.assertEqual(stdout_result['type'], 'stdout')
+        self.assertEqual(stdout_result['log'], b'')
+        self.assertEqual(stderr_result['type'], 'stderr')
+        self.assertEqual(stderr_result['log'], b'')
         self.assertEqual(last_result['status'], 'finished')
         self.assertEqual(last_result['result'], 'pass')
         self.assertEqual(last_result['returncode'], 0)
-        self.assertEqual(last_result['stdout'], b'')
-        self.assertEqual(last_result['stderr'], b'')
         self.assertIn('time', last_result)
 
     @skipUnlessPathExists('/bin/false')
@@ -230,12 +239,16 @@ class Runner(unittest.TestCase):
         runner_klass = runnable.pick_runner_class()
         runner = runner_klass(runnable)
         results = [status for status in runner.run()]
+        stdout_result = results[-3]
+        stderr_result = results[-2]
         last_result = results[-1]
+        self.assertEqual(stdout_result['type'], 'stdout')
+        self.assertEqual(stdout_result['log'], b'')
+        self.assertEqual(stderr_result['type'], 'stderr')
+        self.assertEqual(stderr_result['log'], b'')
         self.assertEqual(last_result['status'], 'finished')
         self.assertEqual(last_result['result'], 'fail')
         self.assertEqual(last_result['returncode'], 1)
-        self.assertEqual(last_result['stdout'], b'')
-        self.assertEqual(last_result['stderr'], b'')
         self.assertIn('time', last_result)
 
     def test_runner_python_unittest_ok(self):
@@ -243,29 +256,31 @@ class Runner(unittest.TestCase):
         runner_klass = runnable.pick_runner_class()
         runner = runner_klass(runnable)
         results = [status for status in runner.run()]
-        output1 = ('----------------------------------------------------------'
-                   '------------\nRan 0 tests in ')
-        output2 = 's\n\nOK\n'
+        output1 = (b'----------------------------------------------------------'
+                   b'------------\nRan 0 tests in ')
+        output2 = b's\n\nOK\n'
+        output = results[-2]
         result = results[-1]
         self.assertEqual(result['status'], 'finished')
         self.assertEqual(result['result'], 'pass')
-        self.assertTrue(result['output'].startswith(output1))
-        self.assertTrue(result['output'].endswith(output2))
+        self.assertTrue(output['log'].startswith(output1))
+        self.assertTrue(output['log'].endswith(output2))
 
     def test_runner_python_unittest_fail(self):
         runnable = nrunner.Runnable('python-unittest', 'unittest.TestCase.fail')
         runner_klass = runnable.pick_runner_class()
         runner = runner_klass(runnable)
         results = [status for status in runner.run()]
-        output1 = ('============================================================='
-                   '=========\nFAIL: fail (unittest.case.TestCase)'
-                   '\nFail immediately, with the given message.')
-        output2 = '\n\nFAILED (failures=1)\n'
+        output1 = (b'============================================================='
+                   b'=========\nFAIL: fail (unittest.case.TestCase)'
+                   b'\nFail immediately, with the given message.')
+        output2 = b'\n\nFAILED (failures=1)\n'
+        output = results[-2]
         result = results[-1]
         self.assertEqual(result['status'], 'finished')
         self.assertEqual(result['result'], 'fail')
-        self.assertTrue(result['output'].startswith(output1))
-        self.assertTrue(result['output'].endswith(output2))
+        self.assertTrue(output['log'].startswith(output1))
+        self.assertTrue(output['log'].endswith(output2))
 
     def test_runner_python_unittest_skip(self):
         runnable = nrunner.Runnable(
@@ -274,28 +289,30 @@ class Runner(unittest.TestCase):
         runner_klass = runnable.pick_runner_class()
         runner = runner_klass(runnable)
         results = [status for status in runner.run()]
-        output1 = ('----------------------------------------------------------'
-                   '------------\nRan 1 test in ')
-        output2 = 's\n\nOK (skipped=1)\n'
+        output1 = (b'----------------------------------------------------------'
+                   b'------------\nRan 1 test in ')
+        output2 = b's\n\nOK (skipped=1)\n'
+        output = results[-2]
         result = results[-1]
         self.assertEqual(result['status'], 'finished')
         self.assertEqual(result['result'], 'skip')
-        self.assertTrue(result['output'].startswith(output1))
-        self.assertTrue(result['output'].endswith(output2))
+        self.assertTrue(output['log'].startswith(output1))
+        self.assertTrue(output['log'].endswith(output2))
 
     def test_runner_python_unittest_error(self):
         runnable = nrunner.Runnable('python-unittest', 'error')
         runner_klass = runnable.pick_runner_class()
         runner = runner_klass(runnable)
         results = [status for status in runner.run()]
-        output1 = ('============================================================='
-                   '=========\nERROR: error')
-        output2 = '\n\nFAILED (errors=1)\n'
+        output1 = (b'============================================================='
+                   b'=========\nERROR: error')
+        output2 = b'\n\nFAILED (errors=1)\n'
+        output = results[-2]
         result = results[-1]
         self.assertEqual(result['status'], 'finished')
         self.assertEqual(result['result'], 'error')
-        self.assertTrue(result['output'].startswith(output1))
-        self.assertTrue(result['output'].endswith(output2))
+        self.assertTrue(output['log'].startswith(output1))
+        self.assertTrue(output['log'].endswith(output2))
 
     def test_runner_python_unittest_empty_uri_error(self):
         runnable = nrunner.Runnable('python-unittest', '')
@@ -328,7 +345,7 @@ echo 'not ok 2 - description 2'"""
             fp.write(tap_script)
 
         runnable = nrunner.Runnable('tap', '/bin/sh', tap_path)
-        runner = nrunner_tap.TAPRunner(runnable)
+        runner = runner_tap.TAPRunner(runnable)
         results = [status for status in runner.run()]
         last_result = results[-1]
         self.assertEqual(last_result['status'], 'finished')
@@ -348,7 +365,7 @@ echo 'ok 2 - description 2'"""
             fp.write(tap_script)
 
         runnable = nrunner.Runnable('tap', '/bin/sh', tap_path)
-        runner = nrunner_tap.TAPRunner(runnable)
+        runner = runner_tap.TAPRunner(runnable)
         results = [status for status in runner.run()]
         last_result = results[-1]
         self.assertEqual(last_result['status'], 'finished')
@@ -368,7 +385,7 @@ echo 'ok 2 - description 2'"""
             fp.write(tap_script)
 
         runnable = nrunner.Runnable('tap', '/bin/sh', tap_path)
-        runner = nrunner_tap.TAPRunner(runnable)
+        runner = runner_tap.TAPRunner(runnable)
         results = [status for status in runner.run()]
         last_result = results[-1]
         self.assertEqual(last_result['status'], 'finished')
@@ -388,7 +405,7 @@ echo 'ok 2 - description 2'"""
             fp.write(tap_script)
 
         runnable = nrunner.Runnable('tap', '/bin/sh', tap_path)
-        runner = nrunner_tap.TAPRunner(runnable)
+        runner = runner_tap.TAPRunner(runnable)
         results = [status for status in runner.run()]
         last_result = results[-1]
         self.assertEqual(last_result['status'], 'finished')
@@ -408,7 +425,7 @@ echo 'ok 2 - description 2'"""
             fp.write(tap_script)
 
         runnable = nrunner.Runnable('tap', '/bin/sh', tap_path)
-        runner = nrunner_tap.TAPRunner(runnable)
+        runner = runner_tap.TAPRunner(runnable)
         results = [status for status in runner.run()]
         last_result = results[-1]
         self.assertEqual(last_result['status'], 'finished')
